sqlalchemy_mptt-stubs
========================
[![PyPI](https://img.shields.io/badge/pypi-0.0.3-orange.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3) [![PyPI](https://img.shields.io/badge/python-3-blue.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3)

Most annotations generated by py pyannotate. It's still unstable.
